# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/b2buy/subscription/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/b2buy/subscription/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "B2buy\\Subscription\\": "packages/b2buy/subscription/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        B2buy\Subscription\Providers\SubscriptionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Subscription'  => B2buy\Subscription\Facades\Subscription::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=B2buy\\SubscriptionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="B2buy\Subscription\Providers\SubscriptionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="B2buy\Subscription\Providers\SubscriptionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="B2buy\Subscription\Providers\SubscriptionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/subscription/{modulename}

**User**

    http://path-to-route-folder/user/subscription/{modulename}

**Public**

    http://path-to-route-folder/subscriptions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/subscription/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/subscription/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/subscription/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/subscription/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/subscription/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/subscription/{modulename}/{slug}
    METHOD: GET